retry

Function retry 

pub async fn retry<F, Fut, T>(operation: F) -> AptosResult<T>
where F: Fn() -> Fut, Fut: Future<Output = AptosResult<T>>,
Convenience function to retry an operation with default config.

Errors

Returns an error if the operation fails and either the maximum number of retries has been exhausted or the error is not retryable according to the default retry configuration.