pub async fn retry_with_config<F, Fut, T>(
config: &RetryConfig,
operation: F,
) -> AptosResult<T>Expand description
Convenience function to retry an operation with custom config.
Errors
Returns an error if the operation fails and either the maximum number of retries has been exhausted or the error is not retryable according to the provided retry configuration.